.. camacq documentation master file, created by
   sphinx-quickstart on Tue Dec 22 00:48:10 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to camacq's documentation!
==================================

Contents:

.. toctree::
   :includehidden:

   source/modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
